@@ -76,7 +76,7 @@ weekday_search(const WeekDays *weekdays, const char *str, size_t len)
 #define CASE_fmt_HH	case 27: case 28: case 29:
 #define CASE_fmt_MI	case 30:
 
-STRING_PTR_FIELD_TYPE date_fmt[] =
+static STRING_PTR_FIELD_TYPE date_fmt[] =
 {
 	"Y", "Yy", "Yyy", "Yyyy", "Year", "Syyyy", "syear",
 	"I", "Iy", "Iyy", "Iyyy",
@@ -117,6 +117,8 @@ PG_FUNCTION_INFO_V1(ora_timestamp_round);
 PG_FUNCTION_INFO_V1(orafce_sysdate);
 PG_FUNCTION_INFO_V1(orafce_sessiontimezone);
 PG_FUNCTION_INFO_V1(orafce_dbtimezone);
+PG_FUNCTION_INFO_V1(orafce_sys_extract_utc);
+PG_FUNCTION_INFO_V1(orafce_sys_extract_utc_oracle_date);
 
 /*
  * Search const value in char array
@@ -1072,3 +1074,50 @@ orafce_dbtimezone(PG_FUNCTION_ARGS)
 {
 	PG_RETURN_TEXT_P(cstring_to_text(orafce_timezone));
 }
+
+
+/********************************************************************
+ *
+ * oracle.sys_extract_utc(timestamp with time zone
+ *
+ * Returns timestamp at utc time zone
+ *
+ ********************************************************************/
+
+Datum
+orafce_sys_extract_utc(PG_FUNCTION_ARGS)
+{
+	PG_RETURN_DATUM(DirectFunctionCall2(timestamptz_zone,
+										CStringGetTextDatum("utc"),
+										PG_GETARG_DATUM(0)));
+}
+
+/********************************************************************
+ *
+ * oracle.sys_extract_utc(oracle.date)
+ *
+ * Returns timestamp at utc time zone, session time zone is used
+ * as default time zone.
+ *
+ ********************************************************************/
+
+Datum
+orafce_sys_extract_utc_oracle_date(PG_FUNCTION_ARGS)
+{
+	TimestampTz loc_ts;
+
+#if PG_VERSION_NUM >=  130000
+
+	loc_ts = timestamp2timestamptz_opt_overflow(PG_GETARG_TIMESTAMP(0), NULL);
+
+#else
+
+	loc_ts = DatumGetTimestampTz(DirectFunctionCall1(timestamp_timestamptz,
+								 PG_GETARG_TIMESTAMP(0)));
+
+#endif
+
+	PG_RETURN_DATUM(DirectFunctionCall2(timestamptz_zone,
+										CStringGetTextDatum("utc"),
+										TimestampTzGetDatum(loc_ts)));
+}
